/*
* Author: SpicePress
* Created by: Imraj khan (Scientech IT)
* Copyright (c) 2017 SpicePress
* Date: 11 Nov, 2019
* http://www.spicethemes.com
*/

.spicepress-customizer-plugin-notify-actions-count {
	display: inline-block;
	z-index: 26;
	margin: 1px 2px 0 0;
	padding: 0 6px;
	border-radius: 10px;
	color: #fff;
	background-color: #d54e21;
	font-size: 9px;
	font-weight: 600;
	line-height: 17px;
	vertical-align: top;
}

div.spicepress-theme-recomended-actions_container {
	margin-bottom: 2em;
	padding: 0 10px;
}

.spicepress-theme-recomended-actions_container p.succes {
	margin: 1em 0;
}

.spicepress-epsilon-recommeded-actions p.title {
	margin-bottom: 0;
	color: #555d66;
	font-size: 14px;
	font-weight: 600;
}

.spicepress-epsilon-recommeded-actions div.description {
	font-size: 12px;
}

.spicepress-epsilon-recommeded-actions .custom-action {
	margin-top: 1em;
	padding-top: 1em;
	border-top: 1px solid #fafafa;
}

.spicepress-epsilon-recommeded-actions .custom-action p {
	margin-top: 0;
}

.spicepress-theme-recomended-actions_container .spicepress-recommeded-actions-container:not(:first-child) {
	overflow: hidden;
	height: 0;
	opacity: 0;
}

.spicepress-theme-recomended-actions_container .spicepress-recommeded-actions-container:first-child {
	height: auto;
	opacity: 1;
}

.spicepress-theme-recomended-actions_container .spicepress-recommeded-actions-container {
	-webkit-transition: opacity 2s;
	/* Safari */
	transition: opacity 2s;
}

.spicepress-theme-recomended-actions_container .hide {
	display: none;
}

.spicepress-customizer-plugin-notify-actions-count.complete {
	background-color: #79ba49;
}

.spicepress-theme-recomended-actions_container #demo_content .button {
	display: block;
	margin-bottom: 1em;
	text-align: center;
}

.spicepress-theme-recomended-actions_container .succes a {
	display: inline-block;
	width: 100%;
	text-align: center;
}

.spicepress-theme-recomended-actions_container .succes a.social {
	width: 49%;
	margin-bottom: 1em;
	padding-top: 4px;
	line-height: 20px;
}

.spicepress-theme-recomended-actions_container .succes a.social span,
.spicepress-theme-recomended-actions_container .succes  span {
	margin-left: 5px;
}

.spicepress-theme-recomended-actions_container .succes {
	padding-top: 4px;
	line-height: 20px;
}

.spicepress-customizer-notify-dismiss-button-recommended-plugin,
.spicepress-customizer-notify-dismiss-recommended-action {
	position: absolute;
	top: 10px;
	left: 10px;
	border-radius: 50%;
	color: #d54e21;
	text-decoration: none;
	cursor: pointer;
}

.spicepress-epsilon-recommeded-actions {
	position: relative;
}

.spicepress-customizer-notify-dismiss-recommended-action,
.spicepress-epsilon-recommeded-actions .spicepress-customizer-notify-dismiss-button-recommended-plugin {
	top: 0;
	left: 0;
}

.spicepress-epsilon-recommeded-actions #temp_load {
	display: -webkit-box;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-ms-flex-align: center;
}

.spicepress-epsilon-recommeded-actions #temp_load img {
	margin: 0 auto;
}

/*Customizer update icon rotate clockwise*/
@keyframes spicepress_rotate {
    from {
        transform:rotate(0deg);
    }
    to {
        transform:rotate(360deg);
    }
}
.button.updating-message:before {
    animation: spicepress_rotate 2s infinite linear !important;
}